# BDcraft-mod-packer

## Intro
A tool to download all mod patch texture packs from [BDcraft.net](https://bdcraft.net) and pack them into one zip file.

## Requirement

You need to have fairy access to Google Drive, or some texture packs may not be downloaded.

## Install

```bash
pip install bdcraft-mod-packer
```

## Usage

Run the command below and wait it to finish.

```bash
python -m bdcraft-mod-packer
```

